//******************************************************************************
// The example creates the Test.txt file and writes some content into it.
// To test the RTCC, the time is read out few times and written into the file. 
//
//
// Tested Platform: mini Controller Board PIC32
// Tested MCU: PIC32MX150F128D
// Tested Compiler: XC32 4.30
//******************************************************************************

#include <xc.h>

#include "LTlib.h"

#include "HW_mini_Sensing_MCU_Board.h"
#include "HW_mini_Sensing_Memory_Card.h"

#include "LTlib_delay.h"
#include "LTlib_delay.c"

#define DECIMAL_SEPARATOR ','
#include "LTlib_utilities.h"
#include "LTlib_utilities.c"

#include "module_IO.h"
#include "module_IO.c"

#include "module_SPI.h"
#include "module_SPI.c"

#include "module_I2C.h"
#include "module_I2C.c"

#define MCP7940_I2C_MODULE_2
#include "MCP7940.h"
#include "MCP7940.c"

#define MEMORY_SPI_MODULE_1
#define MEMORY_BOARD_WITH_RTC
#include "memory_raw.h"
#include "memory_raw.c"

#include "FAT.h"
#include "FAT.c"

const uint8_t FILE_NAME[] = "Test.txt";
const uint8_t TEXT_LENGTH = 26;

int main(void) {
    
    FATFS sd_card;	//Pointer to the mounted memory
    FIL file;		//File pointer

    uint16_t byte_written;

    uint8_t Text_Demo[] = "Test: 1 2 3 4 5 6 7 8 9 10";
    
    IO_set_all_ports_as_inputs();
    
    LED_1_DIR = SET_AS_OUTPUT;
    LED_2_DIR = SET_AS_OUTPUT;
    P16_DIR = SET_AS_OUTPUT;

   
    SPI1_open (SPI_MASTER_DEVICE);

    LED_1 = LED_ON; 
    delay_ms (200);

    LED_1 = LED_OFF; 
    delay_ms (200);
    
    blink_memory_LED (50);
    
    
    RTCC_initialize (100);
    
    //Just set a time for a reference
    RTCC_set_seconds(0x00);
    RTCC_set_minutes(0x52);     
    RTCC_set_hours(0x08);  
    
    // Set a date for the file
    RTCC_set_days(0x15);
    RTCC_set_months(0x05); 
    RTCC_set_years(0x24); 
        
    while (is_memory_inserted () == MEMORY_NOT_DETECTED){
        
    }
    
    P16_OUT = LED_ON;
    
    delay_ms (200);
    
    //*******************************************************
    // Write the file
    //*******************************************************
	if (f_mount(&sd_card, "", 1) == FR_OK) {	                                               
        
        if (f_open(&file, FILE_NAME, FA_CREATE_ALWAYS | FA_READ | FA_WRITE) == FR_OK) {	    
            f_write(&file, Text_Demo, TEXT_LENGTH, &byte_written);	
           
            blink_memory_LED (50);
            delay_ms (1100);
            f_write(&file, &ASCII_New_Line, 1, &byte_written);
            f_write(&file, RTCC_get_time_seconds(), 8, &byte_written);
            
            blink_memory_LED (50);
            delay_ms (1100);
            f_write(&file, &ASCII_New_Line, 1, &byte_written);
            f_write(&file, RTCC_get_time_seconds(), 8, &byte_written);
            
            blink_memory_LED (50);
            delay_ms (1100);
            f_write(&file, &ASCII_New_Line, 1, &byte_written);
            f_write(&file, RTCC_get_time_seconds(), 8, &byte_written);
            blink_memory_LED (50);
            
            delay_ms (1100);
            
            f_close(&file);
            
            // File properly written
            LED_2 = LED_ON;         
        } else {
            //Memory could be opened but file not written
            LED_1 = LED_ON;
        }
    } else {
        //Memory could not be mounted
        LED_1 = LED_ON; 
    }

    
    
    while (1){
        
        if (is_memory_inserted () == MEMORY_NOT_DETECTED){
            P16_OUT = LED_OFF;
            LED_2 = LED_OFF; 
        } else {
            P16_OUT = LED_ON;
        }

    }
}
